# tinyslurpy

Hi! My name is Slurpy, and I am here to help you write your Slurm jobs. I will prompt you for your job parameters and then take care of the rest! <3

## Installation

```bash
pip install tinyslurpy
```

Remember to alias `tinyslurpy` to `slurpy`!

See you soon! <3 ^\_^
